#!/bin/bash

exclude_patterns=(
	'*/gmock/' # embedded GTest and GMock libraries
	'*/breathe' # (potentially) embedded Python module
	'*Android*'
	'*appveyor*'
	'*travis*'
	'*/support' # unused CMake and biicode stuff
	'*/doc/_templates/layout.html' # Google Analytics
	'*/doc/LICENSE.python'
)

gunzip -c | tar --wildcards --delete "${exclude_patterns[@]}" | gzip -c --best

